package
Version:
v0.0.0-...-7609f02
Opens a new window with list of versions in this module.
Published: Dec 10, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 22
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func FatalAfter(delaySec int, msg string) chan struct{}
FatalAfter aborts by logging a fatal message, after a time delay.
The abort can be cancelled by closing the returned channel
Initialize sets the service state from configuration
Serve starts the web service
Source Files
¶
Click to show internal directories.
Click to hide internal directories.